% This script plots various time series quantities of one re more models.
% Note that if regression lines are desired, one ust have installed the
% MATLAB statistics and machine learning toolbox. 
%--------------------------------------------------------------------------
region='Atlantic';  % 'Atlantic', 'USA', or 'World' (case sensitive)
models={'n20v2c','n20v3','cera20c'}; % 'n20v2c', 'n20v3', and/or 'cera20c'
vble='ntc';    %  Options include total number of TCs with LMIs > 40kts (ntc),
               %  number of hurricanes (nhur), number of major hurricanes
               %  (nmajor), number of landfalling TCs (nland), total power
               %  dissipation index( pdi), and power dissipation index at
               %  landfall (pdiland). 
ns=7;          %  Number of years running average
reg_type='linear';  % Regression type, 'linear' or 'Poisson'
%--------------------------------------------------------------------------
qm=max(size(models));
nbm=zeros(1,qm)+1;   % Indices of starting points of time series for each model
%
%  Choose start point of historical record
%
if strcmpi(region,'Atlantic') || strcmpi(region, 'USA')
    nbest=1;
else
    if any(strcmpi(models,'n20v2c')) || any(strcmpi(models,'n20v3'))
        nbest=130;
    else    
        nbest=80;
    end
end    
%
% Load best track file
%
vblebst=[vble,'best'];
xm=zeros(qm+1,200);
ym=zeros(qm+1,200);
%
file=['time_series_files/',region,'_n20v3'];
a=load(file);
xbest=a.x;
ybest=a.(vblebst);
xbest(1:nbest-1)=[];ybest(1:nbest-1)=[];  % Truncate best track record
%
% Determine points to begin averaging for calibration over last 30 years
%
[~,qn]=size(ybest);
if strcmpi(region,'Atlantic') || strcmpi(region,'USA')
    nbeg=max(qn-29,1);
else
    nbeg=1;
end    
%
% Close existing figures and begin plotting
%
close('all')
%
figure('position',[500,100,800,500])
%
% Set colors of model curves
%
newcolors=[0, 0.4470, 0.7410; 0.2, 0.6470, 0.9410; 0.5, 0.5, 0; 0.5, 0.5, 0; ...
    1, 0, 0; 1, 0, 0];
colororder(newcolors);
%
hold on
%
b=zeros(qm,2);
stats=zeros(qm,4);
h=zeros(qm+1,1);
for i=1:qm
    file=['time_series_files/',region,'_',char(models(i))];
    a=load(file);
    x=a.x2;
    y1=a.(vble);
    x(1:nbm(i)-1)=[];
    y1(1:nbm(i)-1)=[];
    [~,qn]=size(y1);
    nbegsyn=max(qn-49,1);
    cal=mean(ybest(nbeg:end))/mean(y1(nbegsyn:end));  % Calibrate last 
        % 30 years of each synthetic time series to synthetic time series to
        %  bestr-track data
    y=y1*cal;
    h(i,:)=plot(runav(x,ns),runav(y,ns),'linewidth',1.5);
    %
    % Next, test to see if statistics toolbox present and if so, do regressions
    %
    V = ver;
    VName = {V.Name};
    if any(strcmpi(VName, 'Statistics and Machine Learning Toolbox'))
        if strcmpi(reg_type,'Poisson')    
            [bc,~,statsp]=glmfit(runav(x,ns),runav(y,ns),'poisson','link','log');
            ym = glmval(bc,runav(x,ns),'log');
            stats(i,3)=statsp.p(2);
        else    
            [b(i,:),~,stats(i,:)]=regressm(runav(x,ns),runav(y,ns));
            ym=b(i,1)+b(i,2)*runav(x,ns);
        end    
        %
        plot(runav(x,ns),ym,'--','linewidth',1.5)
    end   
end    
%
h(qm+1,:)=plot(runav(xbest,ns),runav(ybest,ns),'k','linewidth',2);

hold off
%
set(gca,'fontsize',15,'fontweight','bold')
xlabel('Year')    
ylabel(vble)
%
modelsp=[models,'IBTrACS'];
legend(h,modelsp,'location','best')